# TODO:
# - python package
# - system libs if possible:
#   third_party/libsvm
#
# Conditional build:
%bcond_with	sse2	# use SSE2 instructions

%ifarch pentium4 %{x8664} x32
%define	with_sse2	1
%endif
Summary:	Netflix's VMAF library
Summary(pl.UTF-8):	Biblioteka Netflix VMAF
Name:		vmaf
Version:	2.3.1
Release:	1
License:	BSD+patent
Group:		Libraries
#Source0Download: https://github.com/Netflix/vmaf/releases
Source0:	https://github.com/Netflix/vmaf/archive/v%{version}/%{name}-%{version}.tar.gz
# Source0-md5:	be40a256a3b739ffc2119b45f919d6bf
Patch0:		%{name}-x32.patch
URL:		https://github.com/Netflix/vmaf
BuildRequires:	gcc >= 6:4.8
BuildRequires:	libstdc++-devel >= 6:4.8
BuildRequires:	meson >= 0.47.0
%ifarch %{ix86} %{x8664} x32
BuildRequires:	nasm >= 2.14
%endif
BuildRequires:	ninja >= 1.7.1
BuildRequires:	python3 >= 1:3.6
BuildRequires:	sed >= 4.0
Requires:	%{name}-libs = %{version}-%{release}
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
VMAF is a perceptual video quality assessment algorithm developed by
Netflix.

%description -l pl.UTF-8
VMAF to percepcyjny algorytm oceny jakości obrazu tworzony przez
Netfliksa.

%package libs
Summary:	Netflix VMAF libary
Summary(pl.UTF-8):	Biblioteka Netflix VMAF
Group:		Libraries
%if %{with sse2}
Requires:	cpuinfo(sse2)
%endif

%description libs
Netflix VMAF libary.

%description libs -l pl.UTF-8
Biblioteka Netflix VMAF.

%package devel
Summary:	Netflix VMAF SDK
Summary(pl.UTF-8):	Pakiet programistyczny Netflix VMAF
Group:		Development/Libraries
Requires:	%{name}-libs = %{version}-%{release}
Requires:	libstdc++-devel >= 6:4.8

%description devel
Netflix VMAF SDK.

%description devel -l pl.UTF-8
Pakiet programistyczny Netflix VMAF.

%package static
Summary:	Static Netflix VMAF library
Summary(pl.UTF-8):	Statyczna biblioteka Netflix VMAF
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static Netflix VMAF library.

%description static -l pl.UTF-8
Statyczna biblioteka Netflix VMAF.

%prep
%setup -q
%patch0 -p1

%{__mv} libvmaf/README.md libvmaf/README.libvmaf.md

%if %{without sse2}
%{__sed} -i -e 's,#define ADM_OPT_RECIP_DIVISION,/* & */,' libvmaf/src/feature/adm_options.h
%endif

%build
%if %{with sse2}
# SSE2 requires global support
CFLAGS="%{rpmcflags} -msse2"
CXXFLAGS="%{rpmcxxflags} -msse2"
%endif

# AVX512 is (properly) runtime detected (but SSE2 is probably prerequisite)
%meson build-libvmaf libvmaf \
%if %{with sse2}
	-Denable_avx512=true
%endif

%ninja_build -C build-libvmaf

%install
rm -rf $RPM_BUILD_ROOT

%ninja_install -C build-libvmaf

install build-libvmaf/tools/vmafossexec $RPM_BUILD_ROOT%{_bindir}

%clean
rm -rf $RPM_BUILD_ROOT

%post	libs -p /sbin/ldconfig
%postun	libs -p /sbin/ldconfig

%triggerpostun libs -- vmaf-libs < 1.5.2
# replace library file with soname symlink
rm -f %{_libdir}/libvmaf.so.0
/sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc libvmaf/tools/README.md
%attr(755,root,root) %{_bindir}/vmaf
%attr(755,root,root) %{_bindir}/vmafossexec

%files libs
%defattr(644,root,root,755)
%doc CHANGELOG.md LICENSE README.md libvmaf/README.libvmaf.md
%attr(755,root,root) %{_libdir}/libvmaf.so.*.*.*
%attr(755,root,root) %ghost %{_libdir}/libvmaf.so.1

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libvmaf.so
%{_includedir}/libvmaf
%{_pkgconfigdir}/libvmaf.pc

%files static
%defattr(644,root,root,755)
%{_libdir}/libvmaf.a
%changelog
* Sun Apr 09 2023 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/vmaf.git;a=log;h=master

* Sun Apr 09 2023 Jakub Bogusz <qboosh@pld-linux.org> 2b98918
- updated to 2.3.1

* Mon Apr 26 2021 Jakub Bogusz <qboosh@pld-linux.org> b41388a
- updated to 2.1.1

* Sun Jan 17 2021 Jakub Bogusz <qboosh@pld-linux.org> 7a14634
- added x32 patch (fix asm build with x32 ABI)
- enable (runtime detected) avx512 code on archs supporting at least sse2

* Fri Jan 15 2021 Jakub Bogusz <qboosh@pld-linux.org> dcd1edd
- updated to 2.1.0 (new soname)
- removed obsolete x86-nosimd patch

* Tue Jan 12 2021 Jakub Bogusz <qboosh@pld-linux.org> 84e1680
- updated to 1.5.3
- added x86-nosimd patch (fix x86 build without SIMD enabled)

* Mon Jul 06 2020 Jakub Bogusz <qboosh@pld-linux.org> 6d9c835
- updated to 1.5.2
- removed obsolete shared patch
- added trigger to replace libvmaf.so.0 library file with soname symlink

* Mon Mar 09 2020 Jakub Bogusz <qboosh@pld-linux.org> 02b7abd
- updated to 1.5.1
- updated shared patch (now just add soname)
- removed outdated libdir patch

* Sat Oct 26 2019 Jakub Bogusz <qboosh@pld-linux.org> adc2aaa
- updated to 1.3.15

* Sun Jul 28 2019 Jakub Bogusz <qboosh@pld-linux.org> f55cd42
- updated to 1.3.14

* Thu Feb 14 2019 Jakub Bogusz <qboosh@pld-linux.org> 2143a84
- updated to 1.3.13
- updated libdir patch

* Wed Oct 31 2018 Jakub Bogusz <qboosh@pld-linux.org> a4918af
- updated to 1.3.9
- added libdir, shared patches; build shared library
- use optflags, added sse2 bcond

* Tue Dec 26 2017 Jakub Bogusz <qboosh@pld-linux.org> 7f1d6d4
- very initial, saving work

